---
title: "TCS3472"
linkTitle: "TCS3472"
weight: 4
description: >
  Color Light-to-Digital Converter with IR Filter
---

## Registers

### Blue channel
Blue light as an int. Divide by ambient light to get scaled number.

### Clear channel
This is the ambient amount of detected light.

### Enable
Enable specific components of the peripheral

### Green channel
Green light as an int. Divide by ambient light to get scaled number.

### Red channel
Red light as an int. Divide by ambient light to get scaled number.

## License
Licensed under [Apache-2.0](https://spdx.org/licenses/Apache-2.0.html#licenseText).

_TCS3472 version 0.1.0_

_Based on Cyanobyte spec version 0.1.0_

_Generated from Cyanobyte Codegen version 0.1.0_